@@ -19,6 +19,7 @@
 #
 
 import codecs
+import os
 import os.path
 import re
 import subprocess
@@ -37,12 +38,11 @@ import stratuslab.api.LogUtil as LogUtil
 
 import Defaults
 
-
 # TODO: Move to Defaults
 utilPath = os.path.abspath(os.path.dirname(__file__))
 defaultRepoConfigSection = 'stratuslab_repo'
 defaultRepoConfigPath = '.stratuslab/stratuslab.repo.cfg'
-modulePath = os.path.abspath(os.path.join(utilPath, '..'))
+modulePath = os.path.abspath(os.path.join(utilPath, os.pardir))
 systemsDir = os.path.join(modulePath, 'stratuslab', 'system')
 varLibDir = '/var/lib/stratuslab/python'
 defaultConfigFile = os.path.join(Defaults.ETC_DIR, 'stratuslab.cfg')
@@ -62,49 +62,52 @@ SSH_EXIT_STATUS_ERROR = 255
 SSH_CONNECTION_RETRY_NUMBER = 2
 SSH_CONNECTION_RETRY_SLEEP_MAX = 60
 
-
 UUID_REGEX = '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}'
 RE_UUID = re.compile(UUID_REGEX)
 
 
-def getShareDir():
-    paths = [Defaults.SHARE_DIR,
-             os.path.join(utilPath, 'share'),
-             os.path.join(utilPath, '..', '..', '..', 'share'),
-             os.path.join(utilPath, '..', '..', '..', '..', 'share'),
-             os.path.join(utilPath, '..', '..', 'resources', 'share')]
+def get_share_file(path_elements, additional_path=None):
+    '''
+    Checks the list of possible share directories for a file with
+    the given path elements.  If an additional path is given (which
+    must be absolute and include the path elements already), then
+    this path is checked first.  It returns the first file found or
+    raises an exception if it doesn't exist.
+    '''
+
+    share_paths = [[Defaults.SHARE_DIR],
+                   [utilPath, 'share'],
+                   [modulePath, 'share'],
+                   [modulePath, os.pardir, os.pardir, 'share'],
+                   [modulePath, os.pardir, os.pardir, os.pardir, 'share'],
+                   [modulePath, os.pardir, 'resources', 'share']]
+
+    paths = []
+    for share_path in share_paths:
+        path = share_path + path_elements
+        paths.append(os.path.join(*path))
+
+    if additional_path:
+        paths.insert(0, additional_path)
 
     for path in paths:
         if os.path.exists(path):
             return path
 
-    raise Exception("could not locate share directory; tried:\n%s" % "\n".join(paths))
+    raise Exception("could not locate file; tried:\n%s" % "\n".join(paths))
 
-def getTemplateDir():
-    paths = [Defaults.TEMPLATE_DIR,
-             os.path.join(utilPath, 'share', 'template'),
-             os.path.join(utilPath, '..', '..', '..', 'share', 'template'),
-             os.path.join(utilPath, '..', '..', '..', '..', 'share', 'template'),
-             os.path.join(utilPath, '..', '..', 'resources', 'share', 'template')]
 
-    for path in paths:
-        if os.path.exists(path):
-            return path
+def get_template_file(path_elements, additional_path=None):
+    elements = list(path_elements)
+    elements.insert(0, 'template')
+    return get_share_file(elements, additional_path)
 
-    raise Exception("could not locate template directory; tried:\n%s" % "\n".join(paths))
 
-def getResourcesDir():
-    paths = [Defaults.RESOURCES_DIR,
-             os.path.join(utilPath, 'share', 'resources'),
-             os.path.join(utilPath, '..', '..', '..', 'share', 'resources'),
-             os.path.join(utilPath, '..', '..', '..', '..', 'share', 'resources'),
-             os.path.join(utilPath, '..', '..', 'resources', 'share', 'resources')]
+def get_resources_file(path_elements, additional_path=None):
+    elements = list(path_elements)
+    elements.insert(0, 'template')
+    return get_share_file(elements, additional_path)
 
-    for path in paths:
-        if os.path.exists(path):
-            return path
-
-    raise Exception("could not locate resources directory; tried:\n%s" % "\n".join(paths))
 
 def wget_as_xml(url, savePath):
     request = urllib2.Request(url, None, {'accept': 'application/xml'})
@@ -112,15 +115,18 @@ def wget_as_xml(url, savePath):
     filePutContent(savePath, fd.read())
     fd.close()
 
+
 def wget(url, savePath):
     fd = _wget(url)
     filePutContent(savePath, fd.read())
     fd.close()
 
+
 def wstring_as_xml(url):
     request = urllib2.Request(url, None, {'accept': 'application/xml'})
     return wstring(request)
 
+
 def wstring(url):
     fd = _wget(url)
     return fd.read()
@@ -511,6 +517,16 @@ def importSystem(system):
         raise
 
 
+def loadModule(module_name):
+    namespace = ''
+    name = module_name
+    if name.find('.') != -1:
+        # There's a namespace so we take it into account
+        namespace = '.'.join(name.split('.')[:-1])
+
+    return __import__(name, fromlist=namespace)
+
+
 def validateIp(ipAddress):
     return isValidIpV4(ipAddress) or isValidIpV6(ipAddress)
 
@@ -675,6 +691,12 @@ def getHostnameFromUri(uri):
     return parseUri(uri)[1]
 
 
+def getHostnamePortFromUri(uri):
+    groups = parseUri(uri)
+    port = (groups[2] and ':%s' % groups[2]) or ''
+    return groups[1] + port
+
+
 def getProtoFromUri(uri):
     return parseUri(uri)[0]
 
@@ -708,18 +730,6 @@ def isFalseConfVal(var):
     return (str(var).lower() in ['false', 'no', 'off', '0', '']) or False
 
 
-def importETree():
-    try:
-        import xml.etree.cElementTree as etree  # c-version first
-        return etree
-    except ImportError:
-        try:
-            import xml.etree.ElementTree as etree  # python version
-            return etree
-        except ImportError:
-            raise Exception('failed to import ElementTree')
-
-
 def escapeDoubleQuotes(string, times=1):
     return re.sub('"', '%s"' % ('\\' * times), string)
 
@@ -774,5 +784,35 @@ def getValueInKB(value):
         valueKB = int(valueNum) * (1024 ** unit.index(valueUnit))
     return str(valueKB)
 
+
 def is_uuid(str_uuid):
     return RE_UUID.match(str_uuid)
+
+
+def importETree():
+    try:
+        import xml.etree.cElementTree as etree  # c-version first
+
+        return etree
+    except ImportError:
+        try:
+            import xml.etree.ElementTree as etree  # python version
+
+            return etree
+        except ImportError:
+            raise Exception('failed to import ElementTree')
+
+
+etree = importETree()
+
+
+def etree_from_text(text):
+    """
+    The native fromstring method in etree doesn't handle unicode
+    values correctly without explicit encoding in Python 2.x.  
+    As the Python 2.x is essentially frozen, the python maintainers
+    will not be fixing this in the distribution.
+    """
+    if isinstance(text, unicode):
+        text = text.encode('utf-8')
+    return etree.fromstring(text)
